@@ -1,3 +1,3 @@
-pub mod v1;
+pub mod v1beta2;
 
 pub mod v1beta3;
