@@ -24,7 +24,7 @@ fn main() {
 
         mach_o: { any(target_os = "macos", target_os = "ios") },
 
-        debug_mode: { any(feature = "debug_order", debug_assertions) },
+        debug_mode: { any(feature = "debug_order") },
 
         //TODO: use crate linkme to implement priorities for mach_o
         support_priority: { any(elf,coff) },
