@@ -46,6 +46,7 @@ impl<T: Finaly> Finaly for UnInited<T> {
 }
 
 impl<T> UnInited<T> {
+    #[allow(clippy::declare_interior_mutable_const)] // this is intentianaly used for
     pub const INIT: Self = Self(UnsafeCell::new(MaybeUninit::uninit()));
 }
 
@@ -88,6 +89,7 @@ impl<T> Finaly for DropedUnInited<T> {
 }
 
 impl<T> DropedUnInited<T> {
+    #[allow(clippy::declare_interior_mutable_const)]
     pub const INIT: Self = Self(UnsafeCell::new(MaybeUninit::uninit()));
 }
 
@@ -544,7 +546,7 @@ where
     <<T as Deref>::Target as LazyData>::Target: Debug,
 {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-        f.debug_tuple("WriteGuard").field(&*self).finish()
+        f.debug_tuple("WriteGuard").field(&**self).finish()
     }
 }
 
@@ -571,7 +573,7 @@ where
     <<T as Deref>::Target as LazyData>::Target: Debug,
 {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-        f.debug_tuple("ReadGuard").field(&*self).finish()
+        f.debug_tuple("ReadGuard").field(&**self).finish()
     }
 }
 
@@ -1220,7 +1222,7 @@ fn may_debug<R, F: FnOnce() -> R>(f: F, #[cfg(debug_mode)] info: &Option<StaticI
     }
     #[cfg(debug_mode)]
     {
-        match std::panic::catch_unwind(std::panic::AssertUnwindSafe(|| f())) {
+        match std::panic::catch_unwind(std::panic::AssertUnwindSafe(f)) {
             Ok(r) => r,
             Err(x) => {
                 if x.is::<CyclicPanic>() {
