@@ -882,6 +882,7 @@ macro_rules! impl_mut_lazy {
             /// # Panic
             ///
             /// Panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
+            #[allow(elided_named_lifetimes)]
             pub fn read(&$($static)? self) -> ReadGuard<'_,T> {
                ReadGuard(GenericLockedLazy::init_then_read_lock(&self.__private))
             }
@@ -892,17 +893,20 @@ macro_rules! impl_mut_lazy {
             /// # Panic
             ///
             /// If locks succeeds, panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
+            #[allow(elided_named_lifetimes)]
             pub fn fast_read(&$($static)? self) -> Option<ReadGuard<'_,T>> {
                GenericLockedLazy::fast_init_then_read_lock(&self.__private).map(ReadGuard)
             }
             #[inline(always)]
             /// Get a read lock if the lazy is initialized or an [AccessError]
+            #[allow(elided_named_lifetimes)]
             pub fn try_read(&$($static)? self) -> Result<ReadGuard<'_,T>,AccessError> {
                GenericLockedLazy::try_read_lock(&self.__private).map(ReadGuard)
             }
             #[inline(always)]
             /// if the lazy is not already write locked: get a read lock if the lazy is initialized or an [AccessError].
             /// Otherwise returns `None`
+            #[allow(elided_named_lifetimes)]
             pub fn fast_try_read(&$($static)? self) -> Option<Result<ReadGuard<'_,T>,AccessError>> {
                GenericLockedLazy::fast_try_read_lock(&self.__private).map(|r| r.map(ReadGuard))
             }
@@ -912,6 +916,7 @@ macro_rules! impl_mut_lazy {
             /// # Panic
             ///
             /// Panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
+            #[allow(elided_named_lifetimes)]
             pub fn write(&$($static)? self) -> WriteGuard<'_,T> {
                WriteGuard(GenericLockedLazy::init_then_write_lock(&self.__private))
             }
@@ -922,16 +927,19 @@ macro_rules! impl_mut_lazy {
             /// # Panic
             ///
             /// If locks succeeds, panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
+            #[allow(elided_named_lifetimes)]
             pub fn fast_write(&$($static)? self) -> Option<WriteGuard<'_,T>> {
                GenericLockedLazy::fast_init_then_write_lock(&self.__private).map(WriteGuard)
             }
             #[inline(always)]
             /// Get a read lock if the lazy is initialized or an [AccessError]
+            #[allow(elided_named_lifetimes)]
             pub fn try_write(&$($static)? self) -> Result<WriteGuard<'_,T>,AccessError> {
                GenericLockedLazy::try_write_lock(&self.__private).map(WriteGuard)
             }
             #[inline(always)]
             /// if the lazy is not already read or write locked: get a write lock if the lazy is initialized or an [AccessError] . Otherwise returns `None`
+            #[allow(elided_named_lifetimes)]
             pub fn fast_try_write(&$($static)? self) -> Option<Result<WriteGuard<'_,T>,AccessError>> {
                GenericLockedLazy::fast_try_write_lock(&self.__private).map(|r| r.map(WriteGuard))
             }
@@ -1093,7 +1101,7 @@ macro_rules! impl_mut_lazy {
             /// # Panic
             ///
             /// Panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
-            pub fn read(&'static self) -> ReadGuard<'_,T> {
+            pub fn read(&'static self) -> ReadGuard<'static,T> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::read_lock_unchecked(&self.__private)};
                     assert!(<$checker::<G>>::initialized_is_accessible(Phased::phase(&l)));
@@ -1109,7 +1117,7 @@ macro_rules! impl_mut_lazy {
             ///
             /// If locks succeeds, panics if initialization panics or if initialization has panicked in a previous attempt to initialize.
             #[inline(always)]
-            pub fn fast_read(&'static self) -> Option<ReadGuard<'_,T>> {
+            pub fn fast_read(&'static self) -> Option<ReadGuard<'static,T>> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::fast_read_lock_unchecked(&self.__private)};
                     if let Some(l) = &l {
@@ -1122,7 +1130,7 @@ macro_rules! impl_mut_lazy {
             }
             #[inline(always)]
             /// Get a read lock if the lazy is initialized or an [AccessError]
-            pub fn try_read(&'static self) -> Result<ReadGuard<'_,T>,AccessError> {
+            pub fn try_read(&'static self) -> Result<ReadGuard<'static,T>,AccessError> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::read_lock_unchecked(&self.__private)};
                     let p = Phased::phase(&l);
@@ -1138,7 +1146,7 @@ macro_rules! impl_mut_lazy {
             /// if the lazy is not already write locked: get a read lock if the lazy is initialized
             /// or an [AccessError]. Otherwise returns `None`
             #[inline(always)]
-            pub fn fast_try_read(&'static self) -> Option<Result<ReadGuard<'_,T>,AccessError>> {
+            pub fn fast_try_read(&'static self) -> Option<Result<ReadGuard<'static,T>,AccessError>> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::fast_read_lock_unchecked(&self.__private)};
                     l.map(|l| {
@@ -1160,7 +1168,7 @@ macro_rules! impl_mut_lazy {
             /// Panics if initialization panics or if initialization has panicked in a previous
             /// attempt to initialize.
             #[inline(always)]
-            pub fn write(&'static self) -> WriteGuard<'_,T> {
+            pub fn write(&'static self) -> WriteGuard<'static,T> {
                 WriteGuard(if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::write_lock_unchecked(&self.__private)};
                     assert!(<$checker::<G>>::initialized_is_accessible(Phased::phase(&l)));
@@ -1177,7 +1185,7 @@ macro_rules! impl_mut_lazy {
             /// If locks succeeds, panics if initialization panics or if initialization has
             /// panicked in a previous attempt to initialize.
             #[inline(always)]
-            pub fn fast_write(&'static self) -> Option<WriteGuard<'_,T>> {
+            pub fn fast_write(&'static self) -> Option<WriteGuard<'static,T>> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::fast_write_lock_unchecked(&self.__private)};
                     if let Some(l) = &l {
@@ -1190,7 +1198,7 @@ macro_rules! impl_mut_lazy {
             }
             /// Get a read lock if the lazy is initialized or an [AccessError]
             #[inline(always)]
-            pub fn try_write(&'static self) -> Result<WriteGuard<'_,T>,AccessError> {
+            pub fn try_write(&'static self) -> Result<WriteGuard<'static,T>,AccessError> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::write_lock_unchecked(&self.__private)};
                     let p = Phased::phase(&l);
@@ -1206,7 +1214,7 @@ macro_rules! impl_mut_lazy {
             /// if the lazy is not already read or write locked: get a write lock if the lazy is
             /// initialized or an [AccessError] . Otherwise returns `None`
             #[inline(always)]
-            pub fn fast_try_write(&'static self) -> Option<Result<WriteGuard<'_,T>,AccessError>> {
+            pub fn fast_try_write(&'static self) -> Option<Result<WriteGuard<'static,T>,AccessError>> {
                 if inited::global_inited_hint() {
                     let l = unsafe{GenericLockedLazy::fast_write_lock_unchecked(&self.__private)};
                     l.map(|l| {
@@ -1242,7 +1250,7 @@ macro_rules! impl_mut_lazy {
             /// Return a read lock to the initialized value or an error containing a read lock to
             /// the primed or post uninited value
             pub fn primed_read_non_initializing(&'static self) ->
-               Result<ReadGuard<'_,T>,ReadGuard<'_,T>> {
+               Result<ReadGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe {GenericLockedLazy::read_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if <$checker::<G>>::is_accessible(p) {
@@ -1254,7 +1262,7 @@ macro_rules! impl_mut_lazy {
             #[inline(always)]
             /// Initialize if possible and either return a read lock to the initialized value or an
             /// error containing a read lock to the primed or post uninited value
-            pub fn primed_read(&'static self) -> Result<ReadGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_read(&'static self) -> Result<ReadGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe {GenericLockedLazy::init_then_read_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if <$checker::<G>>::is_accessible(p) {
@@ -1266,7 +1274,7 @@ macro_rules! impl_mut_lazy {
             #[inline(always)]
             /// Return a write lock that refers to the initialized value or an
             /// error containing a read lock that refers to the primed or post uninited value
-            pub fn primed_write_non_initializing(&'static self) -> Result<WriteGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_write_non_initializing(&'static self) -> Result<WriteGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe{GenericLockedLazy::write_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if <$checker::<G>>::is_accessible(p) {
@@ -1279,7 +1287,7 @@ macro_rules! impl_mut_lazy {
             /// Initialize if possible and either return a write lock that refers to the
             /// initialized value or an error containing a read lock that refers to the primed or
             /// post uninited value
-            pub fn primed_write(&'static self) -> Result<WriteGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_write(&'static self) -> Result<WriteGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe{GenericLockedLazy::init_then_write_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if <$checker::<G>>::is_accessible(p) {
@@ -1302,7 +1310,7 @@ macro_rules! impl_mut_lazy {
             /// Return a read lock to the initialized value or an error containing a read lock to
             /// the primed or post uninited value
             pub fn primed_read_non_initializing(&'static self) ->
-               Result<ReadGuard<'_,T>,ReadGuard<'_,T>> {
+               Result<ReadGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe {GenericLockedLazy::read_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if inited::global_inited_hint() {
@@ -1322,7 +1330,7 @@ macro_rules! impl_mut_lazy {
             #[inline(always)]
             /// Initialize if possible and either return a read lock to the initialized value or an
             /// error containing a read lock to the primed or post uninited value
-            pub fn primed_read(&'static self) -> Result<ReadGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_read(&'static self) -> Result<ReadGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe {GenericLockedLazy::init_then_read_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if inited::global_inited_hint() {
@@ -1342,7 +1350,7 @@ macro_rules! impl_mut_lazy {
             #[inline(always)]
             /// Return a write lock that refers to the initialized value or an
             /// error containing a read lock that refers to the primed or post uninited value
-            pub fn primed_write_non_initializing(&'static self) -> Result<WriteGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_write_non_initializing(&'static self) -> Result<WriteGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe{GenericLockedLazy::write_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if inited::global_inited_hint() {
@@ -1363,7 +1371,7 @@ macro_rules! impl_mut_lazy {
             /// Initialize if possible and either return a write lock that refers to the
             /// initialized value or an error containing a read lock that refers to the primed or
             /// post uninited value
-            pub fn primed_write(&'static self) -> Result<WriteGuard<'_,T>,ReadGuard<'_,T>> {
+            pub fn primed_write(&'static self) -> Result<WriteGuard<'static,T>,ReadGuard<'static,T>> {
                let l = unsafe{GenericLockedLazy::init_then_write_lock_unchecked(&self.__private)};
                let p = Phased::phase(&l);
                if inited::global_inited_hint() {
@@ -1753,7 +1761,7 @@ mod test_lazy_finalize {
     static _X: LazyFinalize<A, fn() -> A> = unsafe { LazyFinalize::from_generator(|| A(22)) };
     #[test]
     fn test() {
-        assert_eq!((*_X).0, 22);
+        assert_eq!(_X.0, 22);
     }
 }
 #[cfg(feature = "test_no_global_lazy_hint")]
@@ -1787,7 +1795,7 @@ mod test_local_lazy_finalize {
         unsafe { UnSyncLazyFinalize::from_generator(|| A(22)) };
     #[test]
     fn test() {
-        assert_eq!((*_X).0, 22);
+        assert_eq!(_X.0, 22);
     }
 }
 #[cfg(all(test, feature = "thread_local"))]
