@@ -293,7 +293,7 @@ mod generic {
     }
 
     #[inline(always)]
-    fn whole_lock<'a, T: Sequential + 'a, L: 'a, G: 'a>(
+    fn whole_lock<'a, T: Sequential + 'a, L, G: 'a>(
         s: &'a T,
         lock_nature: impl Fn(Phase) -> LockNature,
         hint: Phase,
@@ -301,7 +301,7 @@ mod generic {
     where
         T::Sequentializer: AsRef<LazySequentializer<L, G>>,
         T::Sequentializer: AsMut<LazySequentializer<L, G>>,
-        L: PhaseLocker<'a, T>,
+        L: 'a + PhaseLocker<'a, T>,
     {
         let this = Sequential::sequentializer(s).as_ref();
 
@@ -309,7 +309,7 @@ mod generic {
     }
 
     #[inline(always)]
-    fn try_whole_lock<'a, T: Sequential + 'a, L: 'a, G: 'a>(
+    fn try_whole_lock<'a, T: Sequential + 'a, L, G: 'a>(
         s: &'a T,
         lock_nature: impl Fn(Phase) -> LockNature,
         hint: Phase,
@@ -317,7 +317,7 @@ mod generic {
     where
         T::Sequentializer: AsRef<LazySequentializer<L, G>>,
         T::Sequentializer: AsMut<LazySequentializer<L, G>>,
-        L: PhaseLocker<'a, T>,
+        L: 'a + PhaseLocker<'a, T>,
     {
         let this = Sequential::sequentializer(s).as_ref();
 
@@ -325,7 +325,7 @@ mod generic {
     }
 
     #[cfg(not(debug_mode))]
-    fn debug_save_thread<T>(_: &T) {}
+    fn debug_save_thread<T>(_: &T) -> Result<(),()> { Ok(()) }
 
     #[cfg(debug_mode)]
     fn debug_save_thread<T: Sequential, L, G>(s: &T) -> DebugGuard<'_, T, L, G>
@@ -348,7 +348,7 @@ mod generic {
         T::Sequentializer: AsRef<LazySequentializer<L, G>>;
 
     #[cfg(debug_mode)]
-    impl<'a, T: Sequential, L, G> Drop for DebugGuard<'a, T, L, G>
+    impl<T: Sequential, L, G> Drop for DebugGuard<'_, T, L, G>
     where
         T::Sequentializer: AsRef<LazySequentializer<L, G>>,
     {
@@ -537,8 +537,8 @@ mod generic {
                 LockResult::None(_) => unsafe { unreachable_unchecked() },
             })
         }
-        #[inline(always)]
 
+        #[inline(always)]
         fn finalize_callback(s: &'a T, f: impl FnOnce(&'a T::Data)) {
             let this = Sequential::sequentializer(s).as_ref();
 
