@@ -163,6 +163,8 @@
 //! to be sure not to access those static before they are initialized.
 //!
 //! ```rust
+//! # #[cfg(support_priority)]
+//! # {
 //! use static_init::dynamic;
 //!
 //! #[dynamic(10)]
@@ -170,6 +172,7 @@
 //!
 //! #[dynamic(0,drop)]
 //! static mut B: Vec<i32> = unsafe {A.clone()};
+//! # }
 //! ```
 //!
 //! Even if A is not declared mutable, the attribute macro convert it into a mutable static to ensure that every
@@ -185,6 +188,8 @@
 //!
 //!
 //! ```rust
+//! # #[cfg(support_priority)]
+//! # {
 //! use static_init::{constructor, destructor};
 //!
 //! #[constructor(10)]
@@ -198,6 +203,7 @@
 //!
 //! #[destructor(10)]
 //! extern "C" fn finaly() {}
+//! # }
 //! ```
 //!
 //! # Debug support
@@ -361,8 +367,8 @@ pub trait Phased {
 ///
 /// The trait is unsafe because the lock should ensure the following lock semantic:
 ///  - if the implementor also implement Sync, the read/write lock semantic should be synchronized
-///  and if no lock is taken, the call to lock should synchronize with the end of the phase
-///  transition that put the target object in its current phase.
+///    and if no lock is taken, the call to lock should synchronize with the end of the phase
+///    transition that put the target object in its current phase.
 ///  - if the implementor is not Sync then the lock should panic if any attempt is made
 ///    to take another lock while a write lock is alive or to take a write lock while there
 ///    is already a read_lock.(the lock should behave as a RefCell).
@@ -390,6 +396,7 @@ unsafe trait Sequentializer<'a, T: Sequential + 'a>: Sized + Phased {
     ) -> Option<LockResult<Self::ReadGuard, Self::WriteGuard>>;
 
     /// Lock the phases of an object in order to ensure atomic phase transition.
+    #[allow(dead_code)]//used with other cfg
     fn lock_mut(target: &'a mut T) -> Self::WriteGuard;
 }
 
@@ -401,8 +408,8 @@ unsafe trait Sequentializer<'a, T: Sequential + 'a>: Sized + Phased {
 /// The trait is unsafe because the implementor must ensure that:
 ///
 ///  - if the implementor also implement Sync, the read/write lock semantic should be synchronized
-///  and if no lock is taken, the call to lock should synchronize with the end of the phase
-///  transition that put the target object in its current phase.
+///    and if no lock is taken, the call to lock should synchronize with the end of the phase
+///    transition that put the target object in its current phase.
 ///  - if the implementor is not Sync then the lock should panic if any attempt is made
 ///    to take another lock while a write lock is alive or to take a write lock while there
 ///    is already a read_lock.(the lock should behave as a RefCell).
@@ -706,6 +713,8 @@ pub use phase::Phase;
 /// An abscence of priority is equivalent to a priority of 0.
 ///
 /// ```
+/// # #[cfg(support_priority)]
+/// # {
 /// # use static_init::constructor;
 /// #[constructor(0)]
 /// extern "C" fn first () {
@@ -716,6 +725,7 @@ pub use phase::Phase;
 /// extern "C" fn then () {
 /// // run before main start
 /// }
+/// # }
 /// ```
 ///
 ///
@@ -731,9 +741,8 @@ pub use phase::Phase;
 /// unixes:
 ///
 /// - program argument as returned by `std::env::args` and environment variables as returned by
-/// `std::env::vars` will be emty on unixes other than linux-gnu. On linux/gnu they will be
-///  empty above priority
-///  65436.
+///   `std::env::vars` will be emty on unixes other than linux-gnu. On linux/gnu they will be
+///   empty above priority 65436.
 ///
 /// - call to `std::thread::current` will panick.
 ///
@@ -787,6 +796,8 @@ pub use static_init_macro::constructor;
 /// An abscence of priority is equivalent to a priority of 0.
 ///
 /// ```
+/// # #[cfg(support_priority)]
+/// # {
 /// # use static_init::destructor;
 /// #[destructor(1)]
 /// extern "C" fn first () {
@@ -797,6 +808,7 @@ pub use static_init_macro::constructor;
 /// extern "C" fn then () {
 /// // run after main return
 /// }
+/// # }
 /// ```
 /// # About rust runtime
 ///
@@ -815,12 +827,12 @@ pub use static_init_macro::destructor;
 /// There are two main categories of statics:
 ///
 /// - *lazy statics* which are statics that are always safe to use. They may be initialized on
-/// first acces or before main is called;
+///   first acces or before main is called;
 ///
 /// - *locked lazy statics* which are the mutable version of lazy statics.
 ///
 /// - *raw statics*, which are initialized at program start-up and absolutely unchecked. Any
-/// access to them requires `unsafe` block;
+///   access to them requires `unsafe` block;
 ///
 /// # Lazy statics
 ///
@@ -978,7 +990,7 @@ pub use static_init_macro::destructor;
 ///
 /// - `drop` in which case the static will be dropped at program exit:
 /// - `prime` which is a static that support access before it is actualy initialized
-/// and after it is droped;
+///   and after it is droped;
 ///
 /// ## Dropped locked lazy statics
 ///
@@ -1014,8 +1026,8 @@ pub use static_init_macro::destructor;
 ///
 /// - a const initialization that happens at compile time
 ///
-/// - a dynamic intialization that happens the first time they are accessed if
-/// if is declared with `lazy` attribute argument or just before.
+/// - a dynamic intialization that happens the first time they are accessed
+///   if is declared with `lazy` attribute argument or just before.
 ///
 /// More over they are conceptualy uninitialized if the type of the statics
 /// implement the `Uninit` trait and is declared with the `drop` attribute argument.
@@ -1098,6 +1110,8 @@ pub use static_init_macro::destructor;
 /// with priority number 0.
 ///
 /// ```
+/// # #[cfg(support_priority)]
+/// # {
 /// # use static_init::dynamic;
 /// //V1 must be initialized first
 /// //because V2 uses the value of V1.
@@ -1107,6 +1121,7 @@ pub use static_init_macro::destructor;
 ///
 /// #[dynamic(10)]
 /// static V2 :Vec<i32> = unsafe{V1.push(3); V1.clone()};
+/// # }
 /// ```
 ///
 /// ## Drop
@@ -1124,6 +1139,8 @@ pub use static_init_macro::destructor;
 /// is given, the drop priority will equal the one of the initialization priority.
 ///
 /// ```
+/// # #[cfg(support_priority)]
+/// # {
 /// # use static_init::dynamic;
 ///
 /// #[dynamic(10, drop)] //equivalent to #[dynamic(10,drop=10)]
@@ -1132,6 +1149,7 @@ pub use static_init_macro::destructor;
 ///
 /// #[dynamic(42, drop=33)]
 /// static mut V2 :Vec<i32> = vec![1,2];
+/// # }
 /// ```
 ///
 /// The drop priorities are sequenced in the reverse order of initialization priority. The smaller
@@ -1141,6 +1159,8 @@ pub use static_init_macro::destructor;
 /// static will be const initialized.
 ///
 /// ```
+/// # #[cfg(support_priority)]
+/// # {
 /// # use static_init::dynamic;
 /// struct A;
 /// impl Drop for A {
@@ -1149,6 +1169,7 @@ pub use static_init_macro::destructor;
 ///
 /// #[dynamic(drop_only=33)]
 /// static V2: A = A;
+/// # }
 /// ```
 pub use static_init_macro::dynamic;
 
