@@ -37,6 +37,7 @@ pub(crate) struct SyncReadPhaseGuard<'a, T: ?Sized>(&'a T, ReadLock<'a>);
 
 pub(crate) struct Mutex<T>(UnsafeCell<T>, SyncPhaseLocker);
 
+#[allow(dead_code)] // the second field is used by drop
 pub(crate) struct MutexGuard<'a, T>(&'a mut T, Lock<'a>);
 
 #[cfg(feature = "lock_statistics")]
@@ -114,7 +115,7 @@ impl Display for LockStatistics {
 // SyncPhaseGuard
 //-------------------
 //
-impl<'a, T> Deref for SyncPhaseGuard<'a, T> {
+impl<T> Deref for SyncPhaseGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
@@ -169,7 +170,7 @@ unsafe impl<'a, T: ?Sized> PhaseGuard<'a, T> for SyncPhaseGuard<'a, T> {
     }
 }
 
-impl<'a, T> Phased for SyncPhaseGuard<'a, T> {
+impl<T> Phased for SyncPhaseGuard<'_, T> {
     #[inline(always)]
     fn phase(this: &Self) -> Phase {
         this.1.on_unlock
@@ -179,7 +180,7 @@ impl<'a, T> Phased for SyncPhaseGuard<'a, T> {
 // SyncReadPhaseGuard
 //-------------------
 //
-impl<'a, T> Deref for SyncReadPhaseGuard<'a, T> {
+impl<T> Deref for SyncReadPhaseGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
@@ -211,14 +212,14 @@ impl<'a, T> From<SyncPhaseGuard<'a, T>> for SyncReadPhaseGuard<'a, T> {
     }
 }
 
-impl<'a, T> Phased for SyncReadPhaseGuard<'a, T> {
+impl<T> Phased for SyncReadPhaseGuard<'_, T> {
     #[inline(always)]
     fn phase(this: &Self) -> Phase {
         this.1.init_phase
     }
 }
 
-impl<'a, T> Clone for SyncReadPhaseGuard<'a, T> {
+impl<T> Clone for SyncReadPhaseGuard<'_, T> {
     fn clone(&self) -> Self {
         SyncReadPhaseGuard(self.0, self.1.clone())
     }
@@ -253,14 +254,14 @@ impl<T> Mutex<T> {
     }
 }
 
-impl<'a, T> Deref for MutexGuard<'a, T> {
+impl<T> Deref for MutexGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
         self.0
     }
 }
-impl<'a, T> DerefMut for MutexGuard<'a, T> {
+impl<T> DerefMut for MutexGuard<'_, T> {
     #[inline(always)]
     fn deref_mut(&mut self) -> &mut T {
         self.0
@@ -293,11 +294,13 @@ impl<'a> Lock<'a> {
         }
     }
     #[inline(always)]
+    #[allow(dead_code)] // used by other impl
     pub fn phase(&self) -> Phase {
         let v = self.futex.load(Ordering::Relaxed);
         Phase::from_bits_truncate(v)
     }
     #[inline(always)]
+    #[allow(dead_code)] // used by other impl
     pub fn xor_phase(&self, xor: Phase) -> Phase {
         let v = self.futex.fetch_xor(xor.bits(), Ordering::Release);
         Phase::from_bits_truncate(v) ^ xor
@@ -313,7 +316,7 @@ impl<'a> Lock<'a> {
         let prev = self.futex.fetch_xor(xor, Ordering::Release);
 
         let r = if prev & READ_WAITER_BIT != 0 {
-            wake_readers(&self.futex, 0, true)
+            wake_readers(self.futex, 0, true)
         } else {
             ReadLock::new(self.futex, self.on_unlock.bits())
         };
@@ -400,7 +403,7 @@ fn transfer_lock(futex: &Futex, mut cur: u32) {
     }
 }
 
-impl<'a> Drop for Lock<'a> {
+impl Drop for Lock<'_> {
     #[inline(always)]
     fn drop(&mut self) {
         //state: old_phase | LOCKED_BIT | <0:READ_WAITER_BIT|0:WRITE_WAITER_BIT>
@@ -426,7 +429,7 @@ impl<'a> Drop for Lock<'a> {
         if has_waiters(prev) {
             //let cur = cur & (READ_WAITER_BIT|WRITE_WAITER_BIT|READER_BITS|READER_OVERF) | p;
             //state: phase | 1:READ_WAITER_BIT<|>1:WRITE_WAITER_BIT
-            transfer_lock(&self.futex, prev ^ xor);
+            transfer_lock(self.futex, prev ^ xor);
         }
     }
 }
@@ -476,7 +479,7 @@ impl<'a> ReadLock<'a> {
     //}
 }
 
-impl<'a> Drop for ReadLock<'a> {
+impl Drop for ReadLock<'_> {
     #[inline(always)]
     fn drop(&mut self) {
         //state: phase | <LOCKED_BIT> | READER_UNITY*n | <0:READ_WAITER_BIT> |<0:WRITE_WAITER_BIT>
@@ -485,18 +488,18 @@ impl<'a> Drop for ReadLock<'a> {
         if has_one_reader(prev) && is_not_write_locked(prev) && has_waiters(prev) {
             //state: phase | READ_WAITER_BIT <|> WRITE_WAITER_BIT
             let cur = prev - READER_UNITY;
-            transfer_lock(&self.futex, cur);
+            transfer_lock(self.futex, cur);
         }
     }
 }
 
-impl<'a> Clone for ReadLock<'a> {
+impl Clone for ReadLock<'_> {
     fn clone(&self) -> Self {
         let mut spin_wait = SpinWait::new();
         let mut cur = self.futex.load(Ordering::Relaxed);
         loop {
             if !has_readers_max(cur) {
-                cur = match read_lock(&self.futex, |cur| !has_readers_max(cur), cur) {
+                cur = match read_lock(self.futex, |cur| !has_readers_max(cur), cur) {
                     Ok(rl) => return rl,
                     Err(cur) => cur,
                 }
@@ -527,7 +530,7 @@ impl<'a> Clone for ReadLock<'a> {
 
                 assert_ne!(cur & (READER_BITS | READER_OVERF), 0);
 
-                return ReadLock::new(&self.futex, cur);
+                return ReadLock::new(self.futex, cur);
             }
 
             spin_wait.reset();
@@ -607,7 +610,7 @@ fn wake_readers(futex: &Futex, to_unactivate: u32, converting: bool) -> ReadLock
 }
 
 struct MutGuard<'a>(&'a mut Futex, Phase);
-impl<'a> Drop for MutGuard<'a> {
+impl Drop for MutGuard<'_> {
     fn drop(&mut self) {
         *self.0.get_mut() = self.1.bits();
     }
@@ -688,7 +691,7 @@ impl SyncPhaseLocker {
     }
     #[inline(always)]
     /// Returns a mutable phase locker
-    pub fn lock_mut<'a, T: ?Sized>(&'a mut self, v: &'a T) -> SyncPhaseGuard<'_, T> {
+    pub fn lock_mut<'a, T: ?Sized>(&'a mut self, v: &'a T) -> SyncPhaseGuard<'a, T> {
         let cur = self.0.fetch_or(LOCKED_BIT, Ordering::Acquire);
         SyncPhaseGuard::new(v, Lock::new(&self.0, cur))
     }
@@ -712,7 +715,7 @@ impl SyncPhaseLocker {
         how: impl Fn(Phase) -> LockNature,
         on_waiting_how: impl Fn(Phase) -> LockNature,
         hint: Phase,
-    ) -> LockResult<SyncReadPhaseGuard<'_, T>, SyncPhaseGuard<'_, T>> {
+    ) -> LockResult<SyncReadPhaseGuard<'a, T>, SyncPhaseGuard<'a, T>> {
         match self.raw_lock(how, on_waiting_how, hint) {
             LockResult::Write(l) => LockResult::Write(SyncPhaseGuard::new(v, l)),
             LockResult::Read(l) => LockResult::Read(SyncReadPhaseGuard::new(v, l)),
@@ -741,7 +744,7 @@ impl SyncPhaseLocker {
         v: &'a T,
         how: impl Fn(Phase) -> LockNature,
         hint: Phase,
-    ) -> Option<LockResult<SyncReadPhaseGuard<'_, T>, SyncPhaseGuard<'_, T>>> {
+    ) -> Option<LockResult<SyncReadPhaseGuard<'a, T>, SyncPhaseGuard<'a, T>>> {
         self.try_raw_lock(how, hint).map(|l| match l {
             LockResult::Write(l) => LockResult::Write(SyncPhaseGuard::new(v, l)),
             LockResult::Read(l) => LockResult::Read(SyncReadPhaseGuard::new(v, l)),
@@ -1103,7 +1106,7 @@ fn read_lock(
             Ordering::Relaxed,
         ) {
             Ok(_) => {
-                return Ok(ReadLock::new(&futex, cur));
+                return Ok(ReadLock::new(futex, cur));
             }
             Err(_) => {
                 inner_spin_wait.spin_no_yield();
@@ -1130,7 +1133,7 @@ fn wait_as_writer_then_wake_with_lock(
 
         assert_ne!(cur & LOCKED_BIT, 0);
 
-        let lock = Lock::new(&futex, cur);
+        let lock = Lock::new(futex, cur);
 
         match how(Phase::from_bits_truncate(cur)) {
             LockNature::Write => return Some(LockResult::Write(lock)),
@@ -1169,7 +1172,7 @@ fn wait_as_reader_then_wake_with_lock(
 
         assert_ne!(cur & (READER_BITS | READER_OVERF), 0);
 
-        let lock = ReadLock::new(&futex, cur);
+        let lock = ReadLock::new(futex, cur);
 
         match how(Phase::from_bits_truncate(cur)) {
             LockNature::Read => return Some(LockResult::Read(lock)),
@@ -1193,7 +1196,7 @@ fn wait_for_readers(futex: &Futex, mut cur: u32) -> Result<Lock<'_>, u32> {
     while spinwait.spin() {
         cur = futex.load(Ordering::Acquire);
         if has_no_readers(cur) {
-            return Ok(Lock::new(&futex, cur));
+            return Ok(Lock::new(futex, cur));
         }
     }
 
@@ -1208,7 +1211,7 @@ fn wait_for_readers(futex: &Futex, mut cur: u32) -> Result<Lock<'_>, u32> {
                 cur = x;
                 if has_no_readers(cur) {
                     fence(Ordering::Acquire);
-                    return Ok(Lock::new(&futex, cur));
+                    return Ok(Lock::new(futex, cur));
                 }
             }
             Ok(_) => {
