@@ -30,12 +30,13 @@ pub(crate) struct SyncReadPhaseGuard<'a, T: ?Sized>(&'a T, ReadLock<'a>);
 
 pub(crate) struct Mutex<T>(UnsafeCell<T>, SyncPhaseLocker);
 
+#[allow(dead_code)]// => the field is used by drop.
 pub(crate) struct MutexGuard<'a, T>(&'a mut T, Lock<'a>);
 
 // SyncPhaseGuard
 //-------------------
 //
-impl<'a, T> Deref for SyncPhaseGuard<'a, T> {
+impl<T> Deref for SyncPhaseGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
@@ -90,7 +91,7 @@ unsafe impl<'a, T: ?Sized> PhaseGuard<'a, T> for SyncPhaseGuard<'a, T> {
     }
 }
 
-impl<'a, T> Phased for SyncPhaseGuard<'a, T> {
+impl<T> Phased for SyncPhaseGuard<'_, T> {
     #[inline(always)]
     fn phase(this: &Self) -> Phase {
         this.1.on_unlock
@@ -100,7 +101,7 @@ impl<'a, T> Phased for SyncPhaseGuard<'a, T> {
 // SyncReadPhaseGuard
 //-------------------
 //
-impl<'a, T> Deref for SyncReadPhaseGuard<'a, T> {
+impl<T> Deref for SyncReadPhaseGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
@@ -132,14 +133,14 @@ impl<'a, T> From<SyncPhaseGuard<'a, T>> for SyncReadPhaseGuard<'a, T> {
     }
 }
 
-impl<'a, T> Phased for SyncReadPhaseGuard<'a, T> {
+impl<T> Phased for SyncReadPhaseGuard<'_, T> {
     #[inline(always)]
     fn phase(this: &Self) -> Phase {
         this.1.init_phase
     }
 }
 
-impl<'a, T> Clone for SyncReadPhaseGuard<'a, T> {
+impl<T> Clone for SyncReadPhaseGuard<'_, T> {
     #[inline(always)]
     fn clone(&self) -> Self {
         Self(self.0, self.1.clone())
@@ -175,14 +176,14 @@ impl<T> Mutex<T> {
     }
 }
 
-impl<'a, T> Deref for MutexGuard<'a, T> {
+impl<T> Deref for MutexGuard<'_, T> {
     type Target = T;
     #[inline(always)]
     fn deref(&self) -> &T {
         self.0
     }
 }
-impl<'a, T> DerefMut for MutexGuard<'a, T> {
+impl<T> DerefMut for MutexGuard<'_, T> {
     #[inline(always)]
     fn deref_mut(&mut self) -> &mut T {
         self.0
@@ -215,11 +216,13 @@ impl<'a> Lock<'a> {
         }
     }
     #[inline(always)]
+    #[allow(dead_code)] // => used by other impl?
     pub fn phase(&self) -> Phase {
         let v = self.futex.load(Ordering::Relaxed);
         Phase::from_bits_truncate(v)
     }
     #[inline(always)]
+    #[allow(dead_code)] // => used by other impl?
     pub fn xor_phase(&self, xor: Phase) -> Phase {
         let v = self.futex.fetch_xor(xor.bits(), Ordering::Release);
         Phase::from_bits_truncate(v) ^ xor
@@ -242,7 +245,7 @@ impl<'a> Lock<'a> {
     }
 }
 
-impl<'a> Drop for Lock<'a> {
+impl Drop for Lock<'_> {
     #[inline(always)]
     fn drop(&mut self) {
         //state: old_phase | LOCKED_BIT
@@ -280,7 +283,7 @@ impl<'a> ReadLock<'a> {
         }
     }
 }
-impl<'a> Clone for ReadLock<'a> {
+impl Clone for ReadLock<'_> {
     fn clone(&self) -> Self {
         let mut spin_wait = SpinWait::new();
         let mut cur = self.futex.load(Ordering::Relaxed);
@@ -297,7 +300,7 @@ impl<'a> Clone for ReadLock<'a> {
                     .is_ok()
             {
                 return ReadLock {
-                    futex: &self.futex,
+                    futex: self.futex,
                     init_phase: self.init_phase,
                 };
             }
@@ -307,7 +310,7 @@ impl<'a> Clone for ReadLock<'a> {
     }
 }
 
-impl<'a> Drop for ReadLock<'a> {
+impl Drop for ReadLock<'_> {
     #[inline(always)]
     fn drop(&mut self) {
         self.futex.fetch_sub(READER_UNITY, Ordering::Release);
@@ -345,7 +348,7 @@ fn is_read_lockable(v: u32) -> bool {
 // ---------------
 //
 struct MutGuard<'a>(&'a mut AtomicU32, Phase);
-impl<'a> Drop for MutGuard<'a> {
+impl Drop for MutGuard<'_> {
     fn drop(&mut self) {
         *self.0.get_mut() = self.1.bits();
     }
@@ -426,7 +429,7 @@ impl SyncPhaseLocker {
     }
     #[inline(always)]
     /// Returns a mutable phase locker
-    pub fn lock_mut<'a, T: ?Sized>(&'a mut self, v: &'a T) -> SyncPhaseGuard<'_, T> {
+    pub fn lock_mut<'a, T: ?Sized>(&'a mut self, v: &'a T) -> SyncPhaseGuard<'a, T> {
         let cur = self.0.fetch_or(LOCKED_BIT, Ordering::Acquire);
         SyncPhaseGuard::new(v, Lock::new(&self.0, cur))
     }
@@ -450,7 +453,7 @@ impl SyncPhaseLocker {
         how: impl Fn(Phase) -> LockNature,
         on_waiting_how: impl Fn(Phase) -> LockNature,
         hint: Phase,
-    ) -> LockResult<SyncReadPhaseGuard<'_, T>, SyncPhaseGuard<'_, T>> {
+    ) -> LockResult<SyncReadPhaseGuard<'a, T>, SyncPhaseGuard<'a, T>> {
         match self.raw_lock(how, on_waiting_how, hint) {
             LockResult::Write(l) => LockResult::Write(SyncPhaseGuard::new(v, l)),
             LockResult::Read(l) => LockResult::Read(SyncReadPhaseGuard::new(v, l)),
@@ -479,7 +482,7 @@ impl SyncPhaseLocker {
         v: &'a T,
         how: impl Fn(Phase) -> LockNature,
         hint: Phase,
-    ) -> Option<LockResult<SyncReadPhaseGuard<'_, T>, SyncPhaseGuard<'_, T>>> {
+    ) -> Option<LockResult<SyncReadPhaseGuard<'a, T>, SyncPhaseGuard<'a, T>>> {
         self.try_raw_lock(how, hint).map(|l| match l {
             LockResult::Write(l) => LockResult::Write(SyncPhaseGuard::new(v, l)),
             LockResult::Read(l) => LockResult::Read(SyncReadPhaseGuard::new(v, l)),
