@@ -1,3 +1,4 @@
+#![allow(static_mut_refs)]
 // Copyright 2021 Olivier Kannengieser
 //
 // Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
@@ -15,7 +16,7 @@ mod test {
     #[dynamic(lazy)]
     static V0: i32 = *V0;
 
-    fn panic_hook(p: &core::panic::PanicInfo<'_>) -> () {
+    fn panic_hook(p: &std::panic::PanicHookInfo<'_>) -> () {
         if p.payload().is::<CyclicPanic>() {
             println!("Cyclic Panic running");
         } else {
@@ -35,7 +36,7 @@ mod test {
     }
 }
 
-fn panic_hook(p: &core::panic::PanicInfo<'_>) -> () {
+fn panic_hook(p: &std::panic::PanicHookInfo<'_>) {
     println!("Panic caught {}", p);
     std::process::exit(1)
 }
