@@ -1,3 +1,4 @@
+#![allow(static_mut_refs)]
 // Copyright 2021 Olivier Kannengieser
 //
 // Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
@@ -26,9 +27,9 @@ mod test {
         }
     }
 
-    fn panic_hook(p: &core::panic::PanicInfo<'_>) -> () {
+    fn panic_hook(p: &std::panic::PanicHookInfo<'_>) -> () {
         println!("Panic caught {}", p);
-        std::process::exit(0)
+        unsafe { libc::_exit(0) }
     }
 
     #[destructor(0)]
